/**
 * This entity describes a character in a work.
 * The character can be original or based on one or more existing characters.
 */
interface WorkCharacterInterface extends IdentifiableInterface, MultiNamedInterface {
  names: Promise<WorkCharacterNameInterface[]> | Identifier[];

  /**
   * the works the character is a part of
   * one work character can be part of multiple works because of series
   */
  works: Promise<WorkInterface[]> | Identifier[];

  /**
   * interaction with other characters as actor
   */
  interactWith: Promise<InteractionTagInterface[]> | Identifier[];

  /**
   * interaction with other characters as receiver
   */
  interactedBy: Promise<InteractionTagInterface[]> | Identifier[];

  /**
   * tags connected to the character
   */
  characterTags: Promise<CharacterTagInterface[]> | Identifier[];

  /**
   * existing characters character is based on
   */
  worldCharacters: Promise<WorldCharacterInterface[]> | Identifier[];
}
